@@ -1,4 +1,4 @@
-//$Id: examplewindow.h,v 1.2 2006/07/10 03:15:33 jjongsma Exp $ -*- c++ -*-
+//$Id: examplewindow.h 705 2006-07-19 02:55:32Z jjongsma $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -19,12 +19,7 @@
 #ifndef GTKMM_EXAMPLEWINDOW_H
 #define GTKMM_EXAMPLEWINDOW_H
 
-#include <gtkmm/window.h>
-#include <gtkmm/box.h>
-#include <gtkmm/scrolledwindow.h>
-#include <gtkmm/textview.h>
-#include <gtkmm/buttonbox.h>
-#include <gtkmm/button.h>
+#include <gtkmm.h>
 
 class ExampleWindow : public Gtk::Window
 {
